@@ -1,12 +1,14 @@
 use {
     crate::*,
+    clap::Parser,
     crossterm::{
         self, cursor,
         terminal::{EnterAlternateScreen, LeaveAlternateScreen},
         QueueableCommand,
     },
     directories_next::ProjectDirs,
-    std::{env, fs, io::Write},
+    std::{fs, io::Write},
+    termimad::EventSource,
 };
 
 /// the type used by all GUI writing functions
@@ -25,15 +27,8 @@ pub fn writer() -> W {
 }
 
 pub fn run() -> anyhow::Result<()> {
-    let mut args: Args = argh::from_env();
+    let mut args: Args = Args::parse();
     args.fix()?;
-    if args.version {
-        println!(
-            "bacon {}",
-            env!("CARGO_PKG_VERSION"),
-        );
-        return Ok(());
-    }
     info!("args: {:#?}", &args);
     let location = MissionLocation::new(&args)?;
     debug!("cargo_toml_file: {:?}", &location.cargo_toml_file);
@@ -76,8 +71,9 @@ pub fn run() -> anyhow::Result<()> {
     } else {
         PackageConfig::default()
     };
+    settings.apply_package_config(&package_config);
 
-    // args are applied after prefs, so that they can override them
+    // args are applied after prefs, and package config so that they can override them
     settings.apply_args(&args);
 
     if args.list_jobs {
@@ -85,14 +81,42 @@ pub fn run() -> anyhow::Result<()> {
         return Ok(());
     }
 
-    let mission = Mission::new(location, &package_config, args.job.as_deref(), settings)?;
-    info!("mission: {:#?}", &mission);
     let mut w = writer();
     w.queue(EnterAlternateScreen)?;
     w.queue(cursor::Hide)?;
-    let r = app::run(&mut w, mission);
+
+    let event_source = EventSource::new()?;
+    let mut job_stack = JobStack::new(&package_config, &settings);
+    let mut next_job = JobRef::Initial;
+    let mut result = Ok(());
+    #[allow(clippy::while_let_loop)]
+    loop {
+        let (job_name, job) = match job_stack.pick_job(&next_job) {
+            Err(e) => {
+                result = Err(e);
+                break;
+            }
+            Ok(Some(t)) => t,
+            Ok(None) => { break; }
+        };
+        let r = Mission::new(&location, job_name, job, &settings)
+            .and_then(|mission| app::run(&mut w, mission, &event_source));
+        match r {
+            Ok(Some(job_ref)) => {
+                next_job = job_ref;
+            }
+            Ok(None) => {
+                break;
+            }
+            Err(e) => {
+                result = Err(e);
+                break;
+            }
+        }
+    }
+
     w.queue(cursor::Show)?;
     w.queue(LeaveAlternateScreen)?;
     w.flush()?;
-    r
+    result
 }
