@@ -1,6 +1,7 @@
 use {
     crate::*,
     anyhow::*,
+    lazy_regex::regex_is_match,
     serde::Deserialize,
     std::{collections::HashMap, fs, path::Path},
 };
@@ -11,22 +12,18 @@ use {
 pub struct PackageConfig {
     pub default_job: String,
     pub jobs: HashMap<String, Job>,
+    pub keybindings: Option<KeyBindings>,
 }
 
 impl PackageConfig {
-    pub fn get_job(&self, name: Option<&str>) -> Result<(&String, &Job)> {
-        let key = name.unwrap_or(&self.default_job);
-        self.jobs
-            .get_key_value(key)
-            .ok_or_else(|| anyhow!("Invalid bacon.toml : job not found: {:?}", key))
-    }
     pub fn from_path(path: &Path) -> Result<Self> {
-        let conf = toml::from_str::<PackageConfig>(&fs::read_to_string(path)?)?;
+        let conf = toml::from_str::<PackageConfig>(&fs::read_to_string(path)?)
+            .with_context(|| format!("Failed to parse configuration file at {:?}", path))?;
         if conf.jobs.is_empty() {
             bail!("Invalid bacon.toml : no job found");
         }
         for (name, job) in &conf.jobs {
-            if name.is_empty() || name.contains('.') || name.contains('/') {
+            if !regex_is_match!(r#"^[\w-]+$"#, name) {
                 bail!(
                     "Invalid bacon.toml : Illegal job name : {:?}",
                     name
