@@ -19,6 +19,7 @@ pub struct Settings {
     pub all_features: bool,
     pub features: Option<String>, // comma separated list
     pub keybindings: KeyBindings,
+    pub export_locations: bool,
 }
 
 impl Settings {
@@ -32,6 +33,9 @@ impl Settings {
         if let Some(b) = prefs.reverse {
             self.reverse = b;
         }
+        if let Some(b) = prefs.export_locations {
+            self.export_locations = b;
+        }
         if prefs.vim_keys == Some(true) {
             self.keybindings.add_vim_keys();
         }
@@ -63,6 +67,12 @@ impl Settings {
         if args.no_reverse {
             self.reverse = false;
         }
+        if args.export_locations {
+            self.export_locations = true;
+        }
+        if args.no_export_locations {
+            self.export_locations = false;
+        }
         if args.reverse {
             self.reverse = true;
         }
